import 'package:hub/backend/api_requests/api_calls.dart';
import 'package:hub/flutter_flow/random_data_util.dart';
import 'package:hub/shared/utils/dialog_util.dart';
import 'package:hub/shared/utils/log_util.dart';

import '/flutter_flow/flutter_flow_util.dart';
import 'sign_up_template_component_widget.dart'
    show SignUpTemplateComponentWidget;
import 'package:flutter/material.dart';

class SignUpTemplateComponentModel
    extends FlutterFlowModel<SignUpTemplateComponentWidget> {
  ///  State fields for stateful widgets in this component.

  final formKey = GlobalKey<FormState>();
  // State field(s) for nameRegisterForm widget.
  FocusNode? nameRegisterFormFocusNode;
  TextEditingController? nameRegisterFormTextController;
  String? Function(BuildContext, String?)?
      nameRegisterFormTextControllerValidator;
  String? _nameRegisterFormTextControllerValidator(
      BuildContext context, String? val) {
    if (val == null || val.isEmpty) {
      return FFLocalizations.of(context).getText(
        '3bs10dfq' /* Campo é necessário */,
      );
    }

    return null;
  }

  // State field(s) for emailRegisterForm widget.
  FocusNode? emailRegisterFormFocusNode;
  TextEditingController? emailRegisterFormTextController;
  String? Function(BuildContext, String?)?
      emailRegisterFormTextControllerValidator;
  String? _emailRegisterFormTextControllerValidator(
      BuildContext context, String? val) {
    if (val == null || val.isEmpty) {
      return FFLocalizations.of(context).getText(
        'mlvw63yj' /* Campo é necessário */,
      );
    }

    if (!RegExp(kTextValidatorEmailRegex).hasMatch(val)) {
      return FFLocalizations.of(context).getText(
        'vobnktrz' /* Insira um email valido. */,
      );
    }
    return null;
  }

  // State field(s) for passwordRegisterForm widget.
  FocusNode? passwordRegisterFormFocusNode;
  TextEditingController? passwordRegisterFormTextController;
  late bool passwordRegisterFormVisibility;
  String? Function(BuildContext, String?)?
      passwordRegisterFormTextControllerValidator;
  String? _passwordRegisterFormTextControllerValidator(
      BuildContext context, String? val) {
    if (val == null || val.isEmpty) {
      return FFLocalizations.of(context).getText(
        '6nn79lmh' /* Campo é necessário */,
      );
    }

    if (val.length < 8) {
      return FFLocalizations.of(context).getText(
        'duq5gpp6' /* A senha deve ter pelo menos 8 ... */,
      );
    }

    return null;
  }

  // Stores action output result for [Action Block - signUpRegisterAction] action in SignUpButtonRegisterForm widget.
  bool? signUp;

  @override
  void initState(BuildContext context) {
    nameRegisterFormTextControllerValidator =
        _nameRegisterFormTextControllerValidator;
    emailRegisterFormTextControllerValidator =
        _emailRegisterFormTextControllerValidator;
    passwordRegisterFormVisibility = false;
    passwordRegisterFormTextControllerValidator =
        _passwordRegisterFormTextControllerValidator;
  }

  @override
  void dispose() {
    nameRegisterFormFocusNode?.dispose();
    nameRegisterFormTextController?.dispose();

    emailRegisterFormFocusNode?.dispose();
    emailRegisterFormTextController?.dispose();

    passwordRegisterFormFocusNode?.dispose();
    passwordRegisterFormTextController?.dispose();
  }

  Future<bool> signUpRegisterAction(
    BuildContext context, {
    required String? name,
    String? passwd,
    required String? email,
    String? device,
  }) async {
    try {
      ApiCallResponse? response;

      if ((email != null && email != '') &&
          (passwd != null && passwd != '' && passwd.length > 7) &&
          (name != null && name != '')) {
        response = await PhpGroup.registerCall.call(
          name: name,
          password: passwd,
          email: email,
          token: randomString(
            36,
            36,
            false,
            false,
            true,
          ),
          uuid: randomString(
            36,
            36,
            false,
            false,
            true,
          ),
          tipo: device,
          descricao: randomString(
            36,
            36,
            true,
            false,
            false,
          ),
        );

        if (response.jsonBody['error'] == false) {
          return true;
        }
        DialogUtil.error(context, response.jsonBody['error_msg']);
        return false;
      } else {
        DialogUtil.errorDefault(context);
        return false;
      }
    } catch (e, s) {
      DialogUtil.errorDefault(context);
      LogUtil.requestAPIFailed(
          'registro.php', email.toString(), "Register", e, s);
      return false;
    }
  }
}
